/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: J9FieldFlags
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class J9FieldFlags {

	// VM Constants

	public static final long SIZEOF;
	public static final long J9FieldFlagConstant;
	public static final long J9FieldFlagHasFieldAnnotations;
	public static final long J9FieldFlagHasGenericSignature;
	public static final long J9FieldFlagHasTypeAnnotations;
	public static final long J9FieldFlagIsContended;
	public static final long J9FieldFlagIsNullRestricted;
	public static final long J9FieldFlagObject;
	public static final long J9FieldFlagPutResolved;
	public static final long J9FieldFlagResolved;
	public static final long J9FieldFlagUnused_4000000;
	public static final long J9FieldFlagsBaseTypeShift;
	public static final long J9FieldSizeDouble;
	public static final long J9FieldTypeBoolean;
	public static final long J9FieldTypeByte;
	public static final long J9FieldTypeChar;
	public static final long J9FieldTypeDouble;
	public static final long J9FieldTypeFloat;
	public static final long J9FieldTypeInt;
	public static final long J9FieldTypeLong;
	public static final long J9FieldTypeMask;
	public static final long J9FieldTypeShort;


	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		J9FieldFlagConstant = 0;
		J9FieldFlagHasFieldAnnotations = 0;
		J9FieldFlagHasGenericSignature = 0;
		J9FieldFlagHasTypeAnnotations = 0;
		J9FieldFlagIsContended = 0;
		J9FieldFlagIsNullRestricted = 0;
		J9FieldFlagObject = 0;
		J9FieldFlagPutResolved = 0;
		J9FieldFlagResolved = 0;
		J9FieldFlagUnused_4000000 = 0;
		J9FieldFlagsBaseTypeShift = 0;
		J9FieldSizeDouble = 0;
		J9FieldTypeBoolean = 0;
		J9FieldTypeByte = 0;
		J9FieldTypeChar = 0;
		J9FieldTypeDouble = 0;
		J9FieldTypeFloat = 0;
		J9FieldTypeInt = 0;
		J9FieldTypeLong = 0;
		J9FieldTypeMask = 0;
		J9FieldTypeShort = 0;
	}

}
