/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: J9HookInterface
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class J9HookInterface {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _J9HookAllocateAgentIDOffset_;
	public static final int _J9HookDeallocateAgentIDOffset_;
	public static final int _J9HookDisableOffset_;
	public static final int _J9HookDispatchOffset_;
	public static final int _J9HookIsEnabledOffset_;
	public static final int _J9HookRegisterOffset_;
	public static final int _J9HookRegisterWithCallSiteOffset_;
	public static final int _J9HookReserveOffset_;
	public static final int _J9HookShutdownInterfaceOffset_;
	public static final int _J9HookUnregisterOffset_;
	public static final int _J9HookUnreserveOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_J9HookAllocateAgentIDOffset_ = 0;
		_J9HookDeallocateAgentIDOffset_ = 0;
		_J9HookDisableOffset_ = 0;
		_J9HookDispatchOffset_ = 0;
		_J9HookIsEnabledOffset_ = 0;
		_J9HookRegisterOffset_ = 0;
		_J9HookRegisterWithCallSiteOffset_ = 0;
		_J9HookReserveOffset_ = 0;
		_J9HookShutdownInterfaceOffset_ = 0;
		_J9HookUnregisterOffset_ = 0;
		_J9HookUnreserveOffset_ = 0;
	}

}
