/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: J9JITGPRSpillArea
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class J9JITGPRSpillArea {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _jitGPRs$named$r10Offset_;
	public static final int _jitGPRs$named$r11Offset_;
	public static final int _jitGPRs$named$r12Offset_;
	public static final int _jitGPRs$named$r13Offset_;
	public static final int _jitGPRs$named$r14Offset_;
	public static final int _jitGPRs$named$r15Offset_;
	public static final int _jitGPRs$named$r8Offset_;
	public static final int _jitGPRs$named$r9Offset_;
	public static final int _jitGPRs$named$raxOffset_;
	public static final int _jitGPRs$named$rbpOffset_;
	public static final int _jitGPRs$named$rbxOffset_;
	public static final int _jitGPRs$named$rcxOffset_;
	public static final int _jitGPRs$named$rdiOffset_;
	public static final int _jitGPRs$named$rdxOffset_;
	public static final int _jitGPRs$named$rsiOffset_;
	public static final int _jitGPRs$named$rspOffset_;
	public static final int _jitGPRs$numberedOffset_;
	public static final int _unusedOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_jitGPRs$named$r10Offset_ = 0;
		_jitGPRs$named$r11Offset_ = 0;
		_jitGPRs$named$r12Offset_ = 0;
		_jitGPRs$named$r13Offset_ = 0;
		_jitGPRs$named$r14Offset_ = 0;
		_jitGPRs$named$r15Offset_ = 0;
		_jitGPRs$named$r8Offset_ = 0;
		_jitGPRs$named$r9Offset_ = 0;
		_jitGPRs$named$raxOffset_ = 0;
		_jitGPRs$named$rbpOffset_ = 0;
		_jitGPRs$named$rbxOffset_ = 0;
		_jitGPRs$named$rcxOffset_ = 0;
		_jitGPRs$named$rdiOffset_ = 0;
		_jitGPRs$named$rdxOffset_ = 0;
		_jitGPRs$named$rsiOffset_ = 0;
		_jitGPRs$named$rspOffset_ = 0;
		_jitGPRs$numberedOffset_ = 0;
		_unusedOffset_ = 0;
	}

}
