/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: J9JVMTIHeapData
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class J9JVMTIHeapData {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _callbacksOffset_;
	public static final int _classFilterOffset_;
	public static final int _clazzOffset_;
	public static final int _currentThreadOffset_;
	public static final int _envOffset_;
	public static final int _eventOffset_;
	public static final int _filterOffset_;
	public static final int _flagsOffset_;
	public static final int _objectOffset_;
	public static final int _objectSizeOffset_;
	public static final int _rcOffset_;
	public static final int _referrerOffset_;
	public static final int _tagsOffset_;
	public static final int _userDataOffset_;
	public static final int _visitRcOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_callbacksOffset_ = 0;
		_classFilterOffset_ = 0;
		_clazzOffset_ = 0;
		_currentThreadOffset_ = 0;
		_envOffset_ = 0;
		_eventOffset_ = 0;
		_filterOffset_ = 0;
		_flagsOffset_ = 0;
		_objectOffset_ = 0;
		_objectSizeOffset_ = 0;
		_rcOffset_ = 0;
		_referrerOffset_ = 0;
		_tagsOffset_ = 0;
		_userDataOffset_ = 0;
		_visitRcOffset_ = 0;
	}

}
