/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: J9SFStackFrame
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class J9SFStackFrame {

	// VM Constants

	public static final long SIZEOF;
	public static final long J9SF_A0_INVISIBLE_TAG;
	public static final long J9SF_A0_REPORT_FRAME_POP_TAG;
	public static final long J9SF_FRAME_TYPE_END_OF_STACK;
	public static final long J9SF_FRAME_TYPE_GENERIC_SPECIAL;
	public static final long J9SF_FRAME_TYPE_JIT_JNI_CALLOUT;
	public static final long J9SF_FRAME_TYPE_JIT_RESOLVE;
	public static final long J9SF_FRAME_TYPE_JNI_NATIVE_METHOD;
	public static final long J9SF_FRAME_TYPE_METHOD;
	public static final long J9SF_FRAME_TYPE_METHODTYPE;
	public static final long J9SF_FRAME_TYPE_NATIVE_METHOD;
	public static final long J9SF_MAX_SPECIAL_FRAME_TYPE;

	// Offsets

	public static final int _savedA0Offset_;
	public static final int _savedCPOffset_;
	public static final int _savedPCOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		J9SF_A0_INVISIBLE_TAG = 0;
		J9SF_A0_REPORT_FRAME_POP_TAG = 0;
		J9SF_FRAME_TYPE_END_OF_STACK = 0;
		J9SF_FRAME_TYPE_GENERIC_SPECIAL = 0;
		J9SF_FRAME_TYPE_JIT_JNI_CALLOUT = 0;
		J9SF_FRAME_TYPE_JIT_RESOLVE = 0;
		J9SF_FRAME_TYPE_JNI_NATIVE_METHOD = 0;
		J9SF_FRAME_TYPE_METHOD = 0;
		J9SF_FRAME_TYPE_METHODTYPE = 0;
		J9SF_FRAME_TYPE_NATIVE_METHOD = 0;
		J9SF_MAX_SPECIAL_FRAME_TYPE = 0;
		_savedA0Offset_ = 0;
		_savedCPOffset_ = 0;
		_savedPCOffset_ = 0;
	}

}
