/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_AllocationStats
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_AllocationStats {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __allocationBytesOffset_;
	public static final int __allocationBytesCumulativeOffset_;
	public static final int __allocationCountOffset_;
	public static final int __allocationSearchCountOffset_;
	public static final int __allocationSearchCountMaxOffset_;
	public static final int __arrayletLeafAllocationBytesOffset_;
	public static final int __arrayletLeafAllocationCountOffset_;
	public static final int __continuationObjectCountOffset_;
	public static final int __discardedBytesOffset_;
	public static final int __ownableSynchronizerObjectCountOffset_;
	public static final int __tlhAllocatedFreshOffset_;
	public static final int __tlhAllocatedReusedOffset_;
	public static final int __tlhAllocatedUsedOffset_;
	public static final int __tlhDiscardedBytesOffset_;
	public static final int __tlhMaxAbandonedListSizeOffset_;
	public static final int __tlhRefreshCountFreshOffset_;
	public static final int __tlhRefreshCountReusedOffset_;
	public static final int __tlhRequestedBytesOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__allocationBytesOffset_ = 0;
		__allocationBytesCumulativeOffset_ = 0;
		__allocationCountOffset_ = 0;
		__allocationSearchCountOffset_ = 0;
		__allocationSearchCountMaxOffset_ = 0;
		__arrayletLeafAllocationBytesOffset_ = 0;
		__arrayletLeafAllocationCountOffset_ = 0;
		__continuationObjectCountOffset_ = 0;
		__discardedBytesOffset_ = 0;
		__ownableSynchronizerObjectCountOffset_ = 0;
		__tlhAllocatedFreshOffset_ = 0;
		__tlhAllocatedReusedOffset_ = 0;
		__tlhAllocatedUsedOffset_ = 0;
		__tlhDiscardedBytesOffset_ = 0;
		__tlhMaxAbandonedListSizeOffset_ = 0;
		__tlhRefreshCountFreshOffset_ = 0;
		__tlhRefreshCountReusedOffset_ = 0;
		__tlhRequestedBytesOffset_ = 0;
	}

}
