/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_CollectionStatisticsStandard
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_CollectionStatisticsStandard {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __loaEnabledOffset_;
	public static final int __macroFragmentedSizeOffset_;
	public static final int __microFragmentedSizeOffset_;
	public static final int __rememberedSetCountOffset_;
	public static final int __scavengerEnabledOffset_;
	public static final int __tenureFragmentationOffset_;
	public static final int __totalFreeLOAHeapSizeOffset_;
	public static final int __totalFreeNurseryHeapSizeOffset_;
	public static final int __totalFreeSurvivorHeapSizeOffset_;
	public static final int __totalFreeTenureHeapSizeOffset_;
	public static final int __totalLOAHeapSizeOffset_;
	public static final int __totalNurseryHeapSizeOffset_;
	public static final int __totalSurvivorHeapSizeOffset_;
	public static final int __totalTenureHeapSizeOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__loaEnabledOffset_ = 0;
		__macroFragmentedSizeOffset_ = 0;
		__microFragmentedSizeOffset_ = 0;
		__rememberedSetCountOffset_ = 0;
		__scavengerEnabledOffset_ = 0;
		__tenureFragmentationOffset_ = 0;
		__totalFreeLOAHeapSizeOffset_ = 0;
		__totalFreeNurseryHeapSizeOffset_ = 0;
		__totalFreeSurvivorHeapSizeOffset_ = 0;
		__totalFreeTenureHeapSizeOffset_ = 0;
		__totalLOAHeapSizeOffset_ = 0;
		__totalNurseryHeapSizeOffset_ = 0;
		__totalSurvivorHeapSizeOffset_ = 0;
		__totalTenureHeapSizeOffset_ = 0;
	}

}
