/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_EnvironmentStandard
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_EnvironmentStandard {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __deferredCopyCacheOffset_;
	public static final int __deferredScanCacheOffset_;
	public static final int __effectiveCopyScanCacheOffset_;
	public static final int __inactiveDeferredCopyCacheOffset_;
	public static final int __inactiveSurvivorCopyScanCacheOffset_;
	public static final int __inactiveTenureCopyScanCacheOffset_;
	public static final int __loaAllocationOffset_;
	public static final int __scavengerRememberedSetOffset_;
	public static final int __survivorCopyScanCacheOffset_;
	public static final int __survivorTLHRemainderBaseOffset_;
	public static final int __survivorTLHRemainderTopOffset_;
	public static final int __tenureCopyScanCacheOffset_;
	public static final int __tenureTLHRemainderBaseOffset_;
	public static final int __tenureTLHRemainderTopOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__deferredCopyCacheOffset_ = 0;
		__deferredScanCacheOffset_ = 0;
		__effectiveCopyScanCacheOffset_ = 0;
		__inactiveDeferredCopyCacheOffset_ = 0;
		__inactiveSurvivorCopyScanCacheOffset_ = 0;
		__inactiveTenureCopyScanCacheOffset_ = 0;
		__loaAllocationOffset_ = 0;
		__scavengerRememberedSetOffset_ = 0;
		__survivorCopyScanCacheOffset_ = 0;
		__survivorTLHRemainderBaseOffset_ = 0;
		__survivorTLHRemainderTopOffset_ = 0;
		__tenureCopyScanCacheOffset_ = 0;
		__tenureTLHRemainderBaseOffset_ = 0;
		__tenureTLHRemainderTopOffset_ = 0;
	}

}
