/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_HeapRegionDataForCompactVLHGC
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_HeapRegionDataForCompactVLHGC {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __blockedListOffset_;
	public static final int __compactDestinationOffset_;
	public static final int __compactScoreOffset_;
	public static final int __isCompactDestinationOffset_;
	public static final int __nextEvacuationCandidateOffset_;
	public static final int __nextInWorkListOffset_;
	public static final int __nextMoveEventCandidateOffset_;
	public static final int __nextRebuildCandidateOffset_;
	public static final int __previousContextOffset_;
	public static final int __projectedLiveBytesRatioOffset_;
	public static final int __shouldCompactOffset_;
	public static final int __shouldFixupOffset_;
	public static final int __vineDepthOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__blockedListOffset_ = 0;
		__compactDestinationOffset_ = 0;
		__compactScoreOffset_ = 0;
		__isCompactDestinationOffset_ = 0;
		__nextEvacuationCandidateOffset_ = 0;
		__nextInWorkListOffset_ = 0;
		__nextMoveEventCandidateOffset_ = 0;
		__nextRebuildCandidateOffset_ = 0;
		__previousContextOffset_ = 0;
		__projectedLiveBytesRatioOffset_ = 0;
		__shouldCompactOffset_ = 0;
		__shouldFixupOffset_ = 0;
		__vineDepthOffset_ = 0;
	}

}
