/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_RealtimeGC
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_RealtimeGC {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __allowGrowthOffset_;
	public static final int __avgPercentFreeHeapAfterCollectOffset_;
	public static final int __currentGCThreadPriorityOffset_;
	public static final int __cycleStateOffset_;
	public static final int __extensionsOffset_;
	public static final int __fixHeapForWalkOffset_;
	public static final int __gcPhaseOffset_;
	public static final int __markingSchemeOffset_;
	public static final int __memoryPoolOffset_;
	public static final int __memorySubSpaceOffset_;
	public static final int __moreTracingRequiredOffset_;
	public static final int __osInterfaceOffset_;
	public static final int __previousCycleBelowTriggerOffset_;
	public static final int __realtimeDelegateOffset_;
	public static final int __schedOffset_;
	public static final int __stopTracingOffset_;
	public static final int __sweepSchemeOffset_;
	public static final int __sweepingArrayletsOffset_;
	public static final int __vmOffset_;
	public static final int __workPacketsOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__allowGrowthOffset_ = 0;
		__avgPercentFreeHeapAfterCollectOffset_ = 0;
		__currentGCThreadPriorityOffset_ = 0;
		__cycleStateOffset_ = 0;
		__extensionsOffset_ = 0;
		__fixHeapForWalkOffset_ = 0;
		__gcPhaseOffset_ = 0;
		__markingSchemeOffset_ = 0;
		__memoryPoolOffset_ = 0;
		__memorySubSpaceOffset_ = 0;
		__moreTracingRequiredOffset_ = 0;
		__osInterfaceOffset_ = 0;
		__previousCycleBelowTriggerOffset_ = 0;
		__realtimeDelegateOffset_ = 0;
		__schedOffset_ = 0;
		__stopTracingOffset_ = 0;
		__sweepSchemeOffset_ = 0;
		__sweepingArrayletsOffset_ = 0;
		__vmOffset_ = 0;
		__workPacketsOffset_ = 0;
	}

}
