/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MM_VerboseEventConcurrentStart
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MM_VerboseEventConcurrentStart {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int __cardCleaningPhase1ThresholdOffset_;
	public static final int __cardCleaningReasonOffset_;
	public static final int __cardsCleanedOffset_;
	public static final int __conCollectionCountOffset_;
	public static final int __lastConTimeOffset_;
	public static final int __threadsScannedCountOffset_;
	public static final int __threadsToScanCountOffset_;
	public static final int __traceTargetOffset_;
	public static final int __tracedByHelpersOffset_;
	public static final int __tracedByMutatorsOffset_;
	public static final int __tracedTotalOffset_;
	public static final int __workStackOverflowCountOffset_;
	public static final int __workStackOverflowOccuredOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		__cardCleaningPhase1ThresholdOffset_ = 0;
		__cardCleaningReasonOffset_ = 0;
		__cardsCleanedOffset_ = 0;
		__conCollectionCountOffset_ = 0;
		__lastConTimeOffset_ = 0;
		__threadsScannedCountOffset_ = 0;
		__threadsToScanCountOffset_ = 0;
		__traceTargetOffset_ = 0;
		__tracedByHelpersOffset_ = 0;
		__tracedByMutatorsOffset_ = 0;
		__tracedTotalOffset_ = 0;
		__workStackOverflowCountOffset_ = 0;
		__workStackOverflowOccuredOffset_ = 0;
	}

}
