/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: MethodContextInfo
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class MethodContextInfo {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _classNameOffset_;
	public static final int _classNameListOffset_;
	public static final int _codeOffset_;
	public static final int _codeLengthOffset_;
	public static final int _constantPoolOffset_;
	public static final int _exceptionTableOffset_;
	public static final int _exceptionTableLengthOffset_;
	public static final int _getExceptionRangeOffset_;
	public static final int _getStringfromClassNameListOffset_;
	public static final int _getUTF8StringfromCPOffset_;
	public static final int _maxLocalsOffset_;
	public static final int _maxStackOffset_;
	public static final int _methodNameOffset_;
	public static final int _modifierOffset_;
	public static final int _portLibOffset_;
	public static final int _romClassOffset_;
	public static final int _signatureOffset_;
	public static final int _stackMapCountOffset_;
	public static final int _stackMapDataOffset_;
	public static final int _stackMapLengthOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_classNameOffset_ = 0;
		_classNameListOffset_ = 0;
		_codeOffset_ = 0;
		_codeLengthOffset_ = 0;
		_constantPoolOffset_ = 0;
		_exceptionTableOffset_ = 0;
		_exceptionTableLengthOffset_ = 0;
		_getExceptionRangeOffset_ = 0;
		_getStringfromClassNameListOffset_ = 0;
		_getUTF8StringfromCPOffset_ = 0;
		_maxLocalsOffset_ = 0;
		_maxStackOffset_ = 0;
		_methodNameOffset_ = 0;
		_modifierOffset_ = 0;
		_portLibOffset_ = 0;
		_romClassOffset_ = 0;
		_signatureOffset_ = 0;
		_stackMapCountOffset_ = 0;
		_stackMapDataOffset_ = 0;
		_stackMapLengthOffset_ = 0;
	}

}
