/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: OSCacheFileConstants
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class OSCacheFileConstants {

	// VM Constants

	public static final long SIZEOF;
	public static final long J9SH_OSCACHE_MMAP_EYECATCHER_LENGTH;
	public static final long J9SH_OSCACHE_MMAP_LOCKID_READWRITELOCK;
	public static final long J9SH_OSCACHE_MMAP_LOCKID_WRITELOCK;
	public static final long J9SH_OSCACHE_MMAP_LOCK_COUNT;
	public static final long OSCACHEMMAP_HEADER_FIELD_ATTACH_LOCK;
	public static final long OSCACHEMMAP_HEADER_FIELD_CREATE_TIME;
	public static final long OSCACHEMMAP_HEADER_FIELD_DATA_LOCKS;
	public static final long OSCACHEMMAP_HEADER_FIELD_HEADER_LOCK;
	public static final long OSCACHEMMAP_HEADER_FIELD_LAST_ATTACHED_TIME;
	public static final long OSCACHEMMAP_HEADER_FIELD_LAST_DETACHED_TIME;


	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		J9SH_OSCACHE_MMAP_EYECATCHER_LENGTH = 0;
		J9SH_OSCACHE_MMAP_LOCKID_READWRITELOCK = 0;
		J9SH_OSCACHE_MMAP_LOCKID_WRITELOCK = 0;
		J9SH_OSCACHE_MMAP_LOCK_COUNT = 0;
		OSCACHEMMAP_HEADER_FIELD_ATTACH_LOCK = 0;
		OSCACHEMMAP_HEADER_FIELD_CREATE_TIME = 0;
		OSCACHEMMAP_HEADER_FIELD_DATA_LOCKS = 0;
		OSCACHEMMAP_HEADER_FIELD_HEADER_LOCK = 0;
		OSCACHEMMAP_HEADER_FIELD_LAST_ATTACHED_TIME = 0;
		OSCACHEMMAP_HEADER_FIELD_LAST_DETACHED_TIME = 0;
	}

}
