/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: SH_OSCache_Info
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class SH_OSCache_Info {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _createtimeOffset_;
	public static final int _generationOffset_;
	public static final int _isCompatibleOffset_;
	public static final int _isCorruptOffset_;
	public static final int _isJavaCorePopulatedOffset_;
	public static final int _javacoreDataOffset_;
	public static final int _lastattachOffset_;
	public static final int _lastdetachOffset_;
	public static final int _layerOffset_;
	public static final int _nameOffset_;
	public static final int _nattachOffset_;
	public static final int _os_semidOffset_;
	public static final int _os_shmidOffset_;
	public static final int _versionDataOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_createtimeOffset_ = 0;
		_generationOffset_ = 0;
		_isCompatibleOffset_ = 0;
		_isCorruptOffset_ = 0;
		_isJavaCorePopulatedOffset_ = 0;
		_javacoreDataOffset_ = 0;
		_lastattachOffset_ = 0;
		_lastdetachOffset_ = 0;
		_layerOffset_ = 0;
		_nameOffset_ = 0;
		_nattachOffset_ = 0;
		_os_semidOffset_ = 0;
		_os_shmidOffset_ = 0;
		_versionDataOffset_ = 0;
	}

}
