/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: UtModuleInfo
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class UtModuleInfo {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _activeOffset_;
	public static final int _containerModuleOffset_;
	public static final int _countOffset_;
	public static final int _formatStringsFileNameOffset_;
	public static final int _groupDetailsOffset_;
	public static final int _intfOffset_;
	public static final int _isAuxiliaryOffset_;
	public static final int _levelsOffset_;
	public static final int _moduleIdOffset_;
	public static final int _nameOffset_;
	public static final int _namelengthOffset_;
	public static final int _nextOffset_;
	public static final int _propertiesOffset_;
	public static final int _referenceCountOffset_;
	public static final int _traceVersionInfoOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_activeOffset_ = 0;
		_containerModuleOffset_ = 0;
		_countOffset_ = 0;
		_formatStringsFileNameOffset_ = 0;
		_groupDetailsOffset_ = 0;
		_intfOffset_ = 0;
		_isAuxiliaryOffset_ = 0;
		_levelsOffset_ = 0;
		_moduleIdOffset_ = 0;
		_nameOffset_ = 0;
		_namelengthOffset_ = 0;
		_nextOffset_ = 0;
		_propertiesOffset_ = 0;
		_referenceCountOffset_ = 0;
		_traceVersionInfoOffset_ = 0;
	}

}
